@@ -6,3 +6,8 @@ class ChatbotActivity(QueryParams):
 
     conversation_id = 'conversation_id', 'Conversation UUID'
     active = 'active', 'Chatbot activity'
+
+class ChatbotActivityStatus(QueryParams):
+    """Parameters for getting chatbot status for a conversation"""
+
+    conversation_id = 'conversation_id', 'Conversation UUID'
