@@ -4,15 +4,17 @@ from sendbee_api.query_params import QueryParams
 class ListMessageTemplates(QueryParams):
     """Parameters for list of message templates API request"""
 
-    approved = 'approved', 'Fetch approved or unapproved templates'
+    status = 'status', 'Fetch templates with desired status'
     search_query = 'search_query', 'Filter contacts by query string'
     page = 'page', 'Page number for pagination'
+    limit = 'limit', 'Number of items per page. Maximum is 100.'
 
 
 class SendTemplateMessage(QueryParams):
     """Parameters for sending template message"""
 
     tags = 'tags', 'Template message tags'
+    button_tags = 'button_tags', 'Template button tags'
     phone = 'phone', 'Contact\'s phone number'
     language = 'language', 'Template message language'
     template_keyword = 'template_keyword', 'Template message keyword'
@@ -34,9 +36,12 @@ class SendMessage(QueryParams):
 class ListConversations(QueryParams):
     """Parameters for list of conversations"""
 
+    date_from = 'date_from', 'Fetch all conversations from this date'
+    date_to = 'date_to', 'Fetch all conversations to this date'
     folder = 'folder', 'Filter conversation by folder'
     search_query = 'search_query', 'Filter conversations by query string'
     page = 'page', 'Page number for pagination'
+    limit = 'limit', 'Number of items per page. Maximum is 100.'
 
 
 class ListMessages(QueryParams):
